@@ -2,7 +2,6 @@ package com.github.bvschaik.julius;
 
 import android.content.Intent;
 import android.net.Uri;
-import android.widget.Toast;
 
 import org.libsdl.app.SDLActivity;
 
@@ -24,6 +23,7 @@ public class JuliusMainActivity extends SDLActivity {
         };
     }
 
+    @SuppressWarnings("unused")
     public void showDirectorySelection(boolean again) {
         startActivityForResult(DirectorySelectionActivity.newIntent(this, again), GET_FOLDER_RESULT);
     }
@@ -41,14 +41,6 @@ public class JuliusMainActivity extends SDLActivity {
         }
     }
 
-    public void toastMessage(final String message) {
-        runOnUiThread(new Runnable() {
-            public void run() {
-                Toast.makeText(getApplicationContext(), message, Toast.LENGTH_SHORT).show();
-            }
-        });
-    }
-
     public float getScreenDensity() {
         return getResources().getDisplayMetrics().density;
     }
